#
# spec file for package ghc-emojis
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name emojis
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.4.1
Release:        1.3
Summary:        Conversion between emoji characters and their names
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
%endif

%description
This package provides functions for converting emoji names to emoji characters
and vice versa.

How does it differ from the 'emoji' package?

- It supports a fuller range of emojis, including all those supported by GitHub
- It supports lookup of emoji aliases from emoji - It uses Text rather than
String - It has a lighter dependency footprint: in particular, it does not
require aeson - It does not require TemplateHaskell.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Jun 18 2024 Peter Simons <psimons@suse.com>
- Update emojis to version 0.1.4.1.
  [#] 0.1.4.1
  * Use foldl' instead of foldr to avoid stack overflows.
* Mon Jun 17 2024 Peter Simons <psimons@suse.com>
- Update emojis to version 0.1.4.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/emojis-0.1.4/src/changelog.md
* Tue Jul 25 2023 Peter Simons <psimons@suse.com>
- Update emojis to version 0.1.3.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/emojis-0.1.3/src/changelog.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Oct 10 2021 psimons@suse.com
- Update emojis to version 0.1.2.
  [#] 0.1.1
  * Update emoji data.
  [#] 0.1.2
  * Update emoji data (Unicode 14.0) and aliases from gemoji.
  * Export `baseEmojis` and `zwjEmojis`, generated directly from
    Unicode emoji data files, so that the library contains a
    complete list of emojis, including emojis for which gemoji
    provides no alias (Stephen Morgan).
* Thu Oct  7 2021 psimons@suse.com
- Update emojis to version 0.1.1.
  Upstream has not updated the file "changelog.md" since the last
  release.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Drop obsolete %%setup hack to work around a missing Setup.hs file.
  New ghc-rpm-macros do this automatically.
* Sat Dec 21 2019 psimons@suse.com
- Add emojis at version 0.1.
